@@ -235,6 +235,7 @@ class MonitorJobSite:
                if   monitorInfo['venueMechanism'] == 'ssh':
                   venue                = monitorInfo['venue']
                   venuePort            = monitorInfo['venuePort']
+                  sshOptions           = monitorInfo['sshOptions']
                   tunnelDesignator     = monitorInfo['tunnelDesignator']
                   user                 = monitorInfo['remoteUser']
                   remoteMonitorCommand = monitorInfo['remoteMonitorCommand']
@@ -244,6 +245,8 @@ class MonitorJobSite:
                   sshCommand.append("-T")
                   sshCommand.append("-x")
                   sshCommand.append("-a")
+                  if sshOptions:
+                     sshCommand += sshOptions.split()
                   sshCommand.append("-i")
                   sshCommand.append(sshIdentity)
                   if tunnelDesignator == "":
@@ -262,6 +265,7 @@ class MonitorJobSite:
                elif monitorInfo['venueMechanism'] == 'gsissh':
                   venue                = monitorInfo['venue']
                   venuePort            = monitorInfo['venuePort']
+                  sshOptions           = monitorInfo['sshOptions']
                   remoteMonitorCommand = monitorInfo['remoteMonitorCommand']
                   x509ProxyPath        = identityPaths['x509']
 
@@ -271,6 +275,8 @@ class MonitorJobSite:
                   sshCommand.append("-T")
                   sshCommand.append("-x")
                   sshCommand.append("-a")
+                  if sshOptions:
+                     sshCommand += sshOptions.split()
                   sshCommand.append("-p")
                   sshCommand.append("%d" % (venuePort))
                   sshCommand.append(venue)
